Actions, Resources, and Condition Keys for Amazon Machine Learning - AWS Identity and Access Management
Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon Machine Learning.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

AWS Identity and Access Management
User Guide

# Actions, Resources, and Condition Keys for Amazon Machine Learning

Amazon Machine Learning (service prefix: `machinelearning`) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service.

- View a list of the API operations available for this service.

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by Amazon Machine Learning
- Resources Defined by Amazon Machine Learning
- Condition Keys for Amazon Machine Learning

## Actions Defined by Amazon Machine Learning

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table.

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
AddTags | Adds one or more tags to an object, up to a limit of 10. Each tag consists of a key and an optional value | Tagging | batchprediction |  |
datasource |  |
evaluation |  |
mlmodel |  |
CreateBatchPrediction | Generates predictions for a group of observations | Write | batchprediction* |  |
datasource* |  |
mlmodel* |  |
CreateDataSourceFromRDS | Creates a DataSource object from an Amazon RDS | Write | datasource* |  |
CreateDataSourceFromRedshift | Creates a DataSource from a database hosted on an Amazon Redshift cluster | Write | datasource* |  |
CreateDataSourceFromS3 | Creates a DataSource object from S3 | Write | datasource* |  |
CreateEvaluation | Creates a new Evaluation of an MLModel | Write | datasource* |  |
evaluation* |  |
mlmodel* |  |
CreateMLModel | Creates a new MLModel | Write | datasource* |  |
mlmodel* |  |
CreateRealtimeEndpoint | Creates a real-time endpoint for the MLModel | Write | mlmodel* |  |
DeleteBatchPrediction | Assigns the DELETED status to a BatchPrediction, rendering it unusable | Write | batchprediction* |  |
DeleteDataSource | Assigns the DELETED status to a DataSource, rendering it unusable | Write | datasource* |  |
DeleteEvaluation | Assigns the DELETED status to an Evaluation, rendering it unusable | Write | evaluation* |  |
DeleteMLModel | Assigns the DELETED status to an MLModel, rendering it unusable | Write | mlmodel* |  |
DeleteRealtimeEndpoint | Deletes a real time endpoint of an MLModel | Write | mlmodel* |  |
DeleteTags | Deletes the specified tags associated with an ML object. After this operation is complete, you can't recover deleted tags | Tagging | batchprediction |  |
datasource |  |
evaluation |  |
mlmodel |  |
DescribeBatchPredictions | Returns a list of BatchPrediction operations that match the search criteria in the request | List |  |  |
DescribeDataSources | Returns a list of DataSource that match the search criteria in the request | List |  |  |
DescribeEvaluations | Returns a list of DescribeEvaluations that match the search criteria in the request | List |  |  |
DescribeMLModels | Returns a list of MLModel that match the search criteria in the request | List |  |  |
DescribeTags | Describes one or more of the tags for your Amazon ML object | List | batchprediction |  |
datasource |  |
evaluation |  |
mlmodel |  |
GetBatchPrediction | Returns a BatchPrediction that includes detailed metadata, status, and data file information | Read | batchprediction* |  |
GetDataSource | Returns a DataSource that includes metadata and data file information, as well as the current status of the DataSource | Read | datasource* |  |
GetEvaluation | Returns an Evaluation that includes metadata as well as the current status of the Evaluation | Read | datasource* |  |
GetMLModel | Returns an MLModel that includes detailed metadata, and data source information as well as the current status of the MLModel | Read | mlmodel* |  |
Predict | Generates a prediction for the observation using the specified ML Model | Write | mlmodel* |  |
UpdateBatchPrediction | Updates the BatchPredictionName of a BatchPrediction | Write | batchprediction* |  |
UpdateDataSource | Updates the DataSourceName of a DataSource | Write | datasource* |  |
UpdateEvaluation | Updates the EvaluationName of an Evaluation | Write | evaluation* |  |
UpdateMLModel | Updates the MLModelName and the ScoreThreshold of an MLModel | Write | mlmodel* |  |

## Resources Defined by Amazon Machine Learning

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The Resource Types Table.

Resource Types | ARN | Condition Keys
--- | --- | ---
batchprediction | `arn:${Partition}:machinelearning:${Region}:${Account}:batchprediction/${BatchPredictionId}` |
datasource | `arn:${Partition}:machinelearning:${Region}:${Account}:datasource/${DatasourceId}` |
evaluation | `arn:${Partition}:machinelearning:${Region}:${Account}:evaluation/${EvaluationId}` |
mlmodel | `arn:${Partition}:machinelearning:${Region}:${Account}:mlmodel/${MlModelId}` |

## Condition Keys for Amazon Machine Learning

Machine Learning has no service-specific context keys that can be used in the `Condition` element of policy statements. For the list of the global context keys that are available to all services, see Available Keys for Conditions in the IAM Policy Reference.

On this page:

- Actions Defined by Amazon Machine Learning
- Resources Defined by Amazon Machine Learning
- Condition Keys for Amazon Machine Learning

We use cookies to provide and improve our services. By using our site, you consent to cookies. Learn more